@@ -113,13 +113,13 @@ they will be documented as producing the modern parse, and the code
 modified to produce this parse if necessary.
 
 The functionality that parses string literals (the C<parse> argument to
-C<new()>) was introduced in version [%% next_version $$], and should be
-considered experimental. It is a bit of a kluge in any case, especially
-in the appropriateness of class names to this use. But the actual
-parsing of a Perl string literal is not too different than the parsing
-of an C<s///> replacement string, so I thought that if someone wanted
-a string literal parse badly enough to deal with the kluginess I could
-provide it fairly easily.
+C<new()>) was introduced in version 0.045, and should be considered
+experimental. It is a bit of a kluge in any case, especially in the
+appropriateness of class names to this use. But the actual parsing of a
+Perl string literal is not too different than the parsing of an C<s///>
+replacement string, so I thought that if someone wanted a string literal
+parse badly enough to deal with the kluginess I could provide it fairly
+easily.
 
 =head1 METHODS
 
@@ -143,7 +143,7 @@ use PPIx::Regexp::Tokenizer;
 use PPIx::Regexp::Util qw{ __choose_tokenizer_class __instance };
 use Scalar::Util qw{ refaddr };
 
-our $VERSION = '0.048_01';
+our $VERSION = '0.049_01';
 
 =head2 new
 
@@ -237,12 +237,15 @@ The default is C<'regex'>.
 
 This option is passed on to the tokenizer, where it specifies whether
 postfix dereferences are recognized in interpolations and code. This
-experimental feature was introduced in Perl 5.19.5. The default is the
-value of C<$PPIx::Regexp::Tokenizer::DEFAULT_POSTDEREF>, which is false
-by default.
+experimental feature was introduced in Perl 5.19.5.
 
-If postfix dereferencing becomes mainstream, the default value of
-C<$PPIx::Regexp::Tokenizer::DEFAULT_POSTDEREF> will become true.
+The default is the value of
+C<$PPIx::Regexp::Tokenizer::DEFAULT_POSTDEREF>, which is true. When
+originally introduced this was false, but was documented as becoming
+true when and if postfix dereferencing became mainstream. The  intent to
+mainstream was announced with Perl 5.23.1, and became official (so to
+speak) with Perl 5.24.0, so the default became true with L<PPIx::Regexp>
+0.049_01.
 
 Note that if L<PPI|PPI> starts unconditionally recognizing postfix
 dereferences, this argument will immediately become ignored, and will be
@@ -596,7 +599,9 @@ sub perl_version_removed {
     defined $v
 	and $v <= 5.021001
 	and return $v;
-    '??' eq $self->delimiters()
+    defined( my $delim = $self->delimiters() )
+	or return $v;
+    '??' eq $delim
 	and '' eq $self->type()->content()
 	and return '5.021001';
     return $v;
