@@ -42,11 +42,11 @@ use PPIx::Regexp::Token::Whitespace		();
 use PPIx::Regexp::Util qw{ __choose_tokenizer_class __instance };
 use Scalar::Util qw{ looks_like_number };
 
-our $VERSION = '0.048_01';
+our $VERSION = '0.049_01';
 
 our $DEFAULT_POSTDEREF;
 defined $DEFAULT_POSTDEREF
-    or $DEFAULT_POSTDEREF = 0;
+    or $DEFAULT_POSTDEREF = 1;
 
 {
     # Names of classes containing tokenization machinery. There are few
@@ -359,10 +359,12 @@ sub get_token {
     my $handler = '__PPIX_TOKENIZER__' . $self->{mode};
 
     my $code = $self->can( $handler )
-	or confess "Getting token in mode '$self->{mode}'. ",
+	or confess 'Programming error - ',
+	    "Getting token in mode '$self->{mode}'. ",
 	    "cursor_curr = $self->{cursor_curr}; ",
 	    "cursor_limit = $self->{cursor_limit}; ",
-	    "length( content ) = ", length $self->{content};
+	    "length( content ) = ", length $self->{content},
+	    "; content = '$self->{content}'";
 
     my $character = substr(
 	$self->{content},
@@ -794,6 +796,8 @@ sub _make_final_token {
 
 sub _set_mode {
     my ( $self, $mode ) = @_;
+    $self->{trace}
+	and warn "Tokenizer going from mode $self->{mode} to $mode\n";
     $self->{mode} = $mode;
     if ( 'kaput' eq $mode ) {
 	$self->{cursor_curr} = $self->{cursor_limit} =
@@ -851,17 +855,32 @@ sub __PPIX_TOKENIZER__init {
 	$self->{trace}
 	    and warn "Tokenizer found regexp end delimiter at $cursor_limit\n";
 	if ( $self->__number_of_extra_parts() ) {
+###	    my $found_embedded_comments;
 	    if ( $self->close_bracket(
 		    $self->{delimiter_start} ) ) {
 		pos $self->{content} = $self->{cursor_curr} +
 		$offset + 1;
+		# If we're bracketed, there may be Perl comments between
+		# the regex and the replacement. PPI gets the parse
+		# wrong as of 1.220, but if we get the handling of the
+		# underlying string right, we will Just Work when PPI
+		# gets it right.
+		while ( $self->{content} =~
+		    m/ \G \s* \n \s* \# [^\n]* /smxgc ) {
+##		    $found_embedded_comments = 1;
+		}
 		$self->{content} =~ m/ \s* /smxgc;
 	    } else {
 		pos $self->{content} = $self->{cursor_curr} +
 		$offset;
 	    }
-	    local $self->{cursor_curr} = pos $self->{content};
-	    local $self->{delimiter_start} = substr
+	    # Localizing cursor_curr and delimiter_start would be
+	    # cleaner, but I don't want the old values restored if a
+	    # parse error occurs.
+	    my $cursor_curr = $self->{cursor_curr};
+	    my $delimiter_start = $self->{delimiter_start};
+	    $self->{cursor_curr} = pos $self->{content};
+	    $self->{delimiter_start} = substr
 		$self->{content},
 		$self->{cursor_curr},
 		1;
@@ -873,12 +892,22 @@ sub __PPIX_TOKENIZER__init {
 		$self->{trace}
 		    and warn "Tokenizer found replacement end delimiter at @{[
 			$self->{cursor_curr} + $s_off ]}\n";
+		$self->{cursor_curr} = $cursor_curr;
+		$self->{delimiter_start} = $delimiter_start;
 	    } else {
+		$self->{trace}
+		    and warn 'Tokenizer failed to find replacement',
+			"end delimiter starting at $self->{cursor_curr}\n";
 		$self->{cursor_curr} = 0;
-		return $self->_make_final_token(
-		    length( $self->{content} ), TOKEN_UNKNOWN, {
-			error	=> 'Tokenizer found mismatched replacement delimiters',
-		    },
+		# TODO If I were smart enough here I could check for
+		# PPI mis-parses like s{foo}
+		#                     #{bar}
+		#                      {baz}
+		# here, doing so if $found_embedded_comments (commented
+		# out above) is true. The problem is that there seem to
+		# as many mis-parses as there are possible delimiters.
+		return $self->__init_error(
+		    'Tokenizer found mismatched replacement delimiters',
 		);
 	    }
 	} else {
@@ -1089,6 +1118,22 @@ sub __PPIX_TOKENIZER__finish {
 
 	if ( $self->close_bracket( $self->{delimiter_start} ) ) {
 	    my $accept;
+	    # If we are bracketed, there can be honest-to-God Perl
+	    # comments between the regexp and the replacement, not just
+	    # regexp comments. As of version 1.220, PPI does not get
+	    # this parse right, but if we can handle this is a string,
+	    # then we will Just Work when PPI gets itself straight.
+	    while ( $self->find_regexp(
+		    qr{ \A ( \s* \n \s* ) ( \# [^\n]* \n ) }smx ) ) {
+		my ( $white_space, $comment ) = $self->capture();
+		push @tokens, $self->make_token(
+		    length $white_space,
+		    'PPIx::Regexp::Token::Whitespace',
+		), $self->make_token(
+		    length $comment,
+		    'PPIx::Regexp::Token::Comment',
+		);
+	    }
 	    $accept = $self->find_regexp( qr{ \A \s+ }smx )
 		and push @tokens, $self->make_token(
 		$accept, 'PPIx::Regexp::Token::Whitespace' );
